@@ -54,18 +54,24 @@ Attributes:
 # Imported modules
 ########################################################################
 
+import logging
 import os
 import re
-import logging
 import tempfile
 import time
 
-from CedarBackup3.util import resolveCommand, executeCommand
-from CedarBackup3.util import convertSize, displayBytes, encodePath
-from CedarBackup3.util import UNIT_SECTORS, UNIT_BYTES, UNIT_KBYTES, UNIT_MBYTES
-from CedarBackup3.writers.util import validateDevice, validateScsiId, validateDriveSpeed
-from CedarBackup3.writers.util import IsoImage
-
+from CedarBackup3.util import (
+    UNIT_BYTES,
+    UNIT_KBYTES,
+    UNIT_MBYTES,
+    UNIT_SECTORS,
+    convertSize,
+    displayBytes,
+    encodePath,
+    executeCommand,
+    resolveCommand,
+)
+from CedarBackup3.writers.util import IsoImage, validateDevice, validateDriveSpeed, validateScsiId
 
 ########################################################################
 # Module-wide constants and variables
